import { isPlatformBrowser } from '@angular/common';
import { InjectionToken, inject, PLATFORM_ID, provideEnvironmentInitializer, Injector } from '@angular/core';
import { createCustomElement } from '@angular/elements';

/**
 * Injection Token for the ECMA `CustomElementRegistry` instance, or
 * `null` if the current platform is not browser.
 * @see https://developer.mozilla.org/en-US/docs/Web/API/CustomElementRegistry
 */
const ELEMENT_REGISTRY = new InjectionToken('ELEMENT_REGISTRY', {
    factory: () => {
        const platform = inject(PLATFORM_ID);
        if (!isPlatformBrowser(platform))
            return null;
        return window.customElements;
    },
});

/**
 * A declarative approach to register Angular Elements.
 *
 * The elements can be either provided synchronously or asynchronously
 * via a promise.
 *
 * @remarks Noop if the current platform is not browser.
 *
 * @example
 *  ```ts
 *  export const appElements: Elements = {
 *    'my-button': ButtonComponent,
 *    'my-icon': IconComponent,
 *    'my-icon-button': IconButtonComponent,
 *  };
 *  ```
 *  ```ts
 *  providers: [
 *    provideElements(appElements),
 *  ]
 *  ```
 *  ```ts
 *  providers: [
 *    provideElements(import('./app-elements').then(m => m.appElements)),
 *  ]
 *  ```
 */
function provideElements(elements) {
    return provideEnvironmentInitializer(async () => {
        const registry = inject(ELEMENT_REGISTRY);
        if (!registry)
            return;
        const injector = inject(Injector);
        for (const [name, type] of Object.entries(await elements)) {
            const element = createCustomElement(type, { injector });
            registry.define(name, element);
        }
    });
}

/**
 * Generated bundle index. Do not edit.
 */

export { ELEMENT_REGISTRY, provideElements };
//# sourceMappingURL=angularity-elements.mjs.map
